@@ -70,7 +70,7 @@ class AutoML:
             if self.search_space:
                 print("You can't use a search space when using optuna")
             multi_class = False
-            if len(np.unique(y)) > 2:
+            if len(np.unique(y)) > 2 and self.task == 'classification' :
                 multi_class = True
 
             Optuna = OptunaSearch(n_trials=self.n_trials, task=self.task,
