@@ -6,7 +6,7 @@ import numpy as np
 class Metrics:
     def __theil_stat__(y_true, y_pred):
         ''' Computes theils bias statistics'''
-        return (np.mean(y_pred) - np.mean(y_true))/np.mean((y_pred - y_true)**2)
+        return (np.mean(y_pred) - np.mean(np.array(y_true)))/np.mean(((y_pred - np.array(y_true)))**2)
 
     def theil_stat():
         '''Computes make scorer for theil bias statistics'''
