@@ -1,4 +1,5 @@
 import copy
+from re import M
 import numpy as np
 import pandas as pd
 from sklearn.pipeline import Pipeline
@@ -74,7 +75,7 @@ class GridSearch:
     def __retrieve_search_space_single_model__(self, models, search_space, task):
         model_space = []
         for model in models:
-            if model in ['xgb', 'catboost', 'adaboost', 'lgbm', 'logistic_regressor', 'svr', 'decision_tree']:
+            if model in ['xgb', 'catboost', 'adaboost', 'lgbm', 'logistic_regression', 'svr', 'decision_tree']:
                 for item in search_space:
                     if task == 'classification':
                         if item['estimator'][0] == model:
@@ -93,13 +94,13 @@ class GridSearch:
     def __set_search_space_single_models__(self, models, task):
         model_space = []
         for model in models:
-            if model in ['xgb', 'catboost', 'adaboost', 'lgbm', 'logistic_regressor', 'svr', 'decision_tree']:
+            if model in ['xgb', 'catboost', 'adaboost', 'lgbm', 'logistic_regression', 'svr', 'decision_tree']:
                 model_space.append(SearchSpaces.get_enum(model, task)[0])
             else:
                 print("Model ", model, " is not in the AutoML yet")
         if not model_space:
             raise BaseException("None of the given models were added to this tool."+ 
-            "The options are: 'xgb', 'catboost', 'adaboost', 'lgbm', 'logistic_regressor', 'svr', 'decision_tree'")
+            "The options are: 'xgb', 'catboost', 'adaboost', 'lgbm', 'logistic_regression', 'svr', 'decision_tree'")
         self.search_space = model_space
 
 
@@ -205,7 +206,7 @@ class GridSearch:
                     pipe = Pipeline(steps=[('imputer',  Base.CustomImputer()),
                                             ('dummie', Base.GetDummiesTransformer()),
                                             ('estimator', Base.Estimator(LGBMClassifier(**params)))])
-                elif item['estimator'] == 'logistic_regressor':
+                elif item['estimator'] == 'logistic_regression':
                     params.pop('estimator')
                     pipe = Pipeline(steps=[('imputer',Base.CustomImputer() ),
                                         ('dummie', Base.GetDummiesTransformer()),
@@ -291,7 +292,7 @@ class GridSearch:
                                                 ('dummie', Base.GetDummiesTransformer()),
                                                 ('fs', Base.FeatureSelector( fs_settings)),
                                                 ('estimator', Base.Estimator(LGBMClassifier(**params)))])
-                    elif item['estimator'] == 'logistic_regressor':
+                    elif item['estimator'] == 'logistic_regression':
                         params.pop('estimator')
                         pipe = Pipeline(steps=[('imputer',Base.CustomImputer()),
                                                 ('dummie', Base.GetDummiesTransformer()),
@@ -347,12 +348,13 @@ class GridSearch:
             Finds the best model among the models returned by grid search"
         '''
         best_result_classification = 0
+        best_result_regresion = None
         y_pred = models[0].predict(X_test)
-        best_result_regresion = Metrics.__theil_stat__(y_test, y_pred)
         if task == 'classification':
             best_model = {'model': models[0],
                           'auc': best_result_classification}
         elif task == 'regression':
+            best_result_regresion = Metrics.__theil_stat__(y_test, y_pred)
             best_model = {'model': models[0],
                           'theil_stat': best_result_regresion}
 
@@ -360,7 +362,12 @@ class GridSearch:
             y_pred = model.predict(X_test)
             if task == 'classification':
                 if not self.compute_ks:
-                    value = roc_auc_score(y_test, y_pred)
+                    value = None
+                    if len(np.unique(y_test)) > 2:
+                        y_pred = model.predict_proba(X_test)           
+                        value = roc_auc_score(y_test, y_pred,multi_class= 'ovo',   average='weighted')
+                    else:
+                        value = roc_auc_score(y_test, y_pred)
                     if value > best_result_classification:
                         best_model = {'model': model, 'auc': value}
                         best_result_classification = value
