@@ -427,8 +427,9 @@ class OptunaObjectives:
         return Metrics.__theil_stat__(y, y_pred)
 
     def __objective__logistic_regression__(trial, X, y):
-        params = {'solver': trial.suggest_categorical('solver', ['newton-cg', 'lbfgs', 'liblinear', 'sag', 'saga']),
-                  'C': trial.suggest_uniform('C', 0.3, 1)}
+        params = {
+                'solver': trial.suggest_categorical('solver', ['lbfgs', 'liblinear', 'sag', 'saga']),
+                'C': trial.suggest_uniform('C', 0.3, 1)}
         logistic = LogisticRegression(**params)
 
         try:
@@ -436,7 +437,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:][feat] = X[feat].astype('float64')
+                    X.loc[:][feat] = X[:][feat].astype('float64')
         except:
             pass
 
@@ -467,7 +468,7 @@ class OptunaObjectives:
                                 or X[col].dtypes == 'int' or X[col].dtypes == 'float']
             if numeric_features:
                 for feat in numeric_features:
-                    X.loc[:, feat] = X[feat].copy().astype('float64')
+                    X.loc[:][feat] = X[feat].copy().astype('float64')
         except:
             pass
 
